@@ -17,15 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
-# DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
-DRYRUNOPERATION = 'DryRunOperation'
-
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
-# 实名认证失败。
-FAILEDOPERATION_ACCOUNTVERIFYFAIL = 'FailedOperation.AccountVerifyFail'
-
 # 年龄限制无法使用电子签服务，请联系客服咨询处理。
 FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalLegal'
 
@@ -35,6 +29,9 @@ FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 # 流程未找到关联的电子文件信息，请检查操作步骤，检查参数，并在修改后重试。
 FAILEDOPERATION_FLOWHASNODOCUMENT = 'FailedOperation.FlowHasNoDocument'
 
+# 身份信息校验不通过，请确认后重试。
+FAILEDOPERATION_IDCARDNUMBERCHECKFAILED = 'FailedOperation.IdCardNumberCheckFailed'
+
 # 当前无可用的许可
 FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
 
@@ -140,6 +137,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 不合法的签署人类型，请检查后重试。
 INVALIDPARAMETER_APPROVERTYPE = 'InvalidParameter.ApproverType'
 
+# 不合法的授权方式，请检查修改后重试。
+INVALIDPARAMETER_AUTHORIZATIONTYPE = 'InvalidParameter.AuthorizationType'
+
 # 不合法的业务id，请检查是否传递，检查是否超过接口上限数量，并在修改后重试。
 INVALIDPARAMETER_BUSINESSID = 'InvalidParameter.BusinessId'
 
@@ -239,9 +239,6 @@ INVALIDPARAMETER_INVALIDNAME = 'InvalidParameter.InvalidName'
 # 参数Offset不正确。
 INVALIDPARAMETER_INVALIDOFFSET = 'InvalidParameter.InvalidOffset'
 
-# OpenId不正确。
-INVALIDPARAMETER_INVALIDOPENID = 'InvalidParameter.InvalidOpenId'
-
 # 操作人ID不正确。
 INVALIDPARAMETER_INVALIDOPERATORID = 'InvalidParameter.InvalidOperatorId'
 
@@ -260,8 +257,8 @@ INVALIDPARAMETER_INVALIDROLENAME = 'InvalidParameter.InvalidRoleName'
 # 实名认证渠道不正确。
 INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 
-# 验证码不正确。
-INVALIDPARAMETER_INVALIDVERIFYCODE = 'InvalidParameter.InvalidVerifyCode'
+# 不合法的跳转链接，请联系电子签客服添加链接白名单。
+INVALIDPARAMETER_JUMPURL = 'InvalidParameter.JumpUrl'
 
 # Limit参数超出最大限制
 INVALIDPARAMETER_LIMIT = 'InvalidParameter.Limit'
@@ -314,6 +311,12 @@ INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'
 # 参数包含有敏感词
 INVALIDPARAMETER_SENSITIVE = 'InvalidParameter.Sensitive'
 
+# 上传的文件包含敏感（不合规）的内容，请确认。
+INVALIDPARAMETER_SENSITIVEFILECONTENT = 'InvalidParameter.SensitiveFileContent'
+
+# 参数错误,暂不支持该种签署控件类型
+INVALIDPARAMETER_SIGNCOMPONENTTYPE = 'InvalidParameter.SignComponentType'
+
 # 签署控件参数不合法，请检查后重试。
 INVALIDPARAMETER_SIGNCOMPONENTS = 'InvalidParameter.SignComponents'
 
@@ -332,6 +335,12 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 无效的手机号
 INVALIDPARAMETERVALUE_INVALIDMOBILE = 'InvalidParameterValue.InvalidMobile'
 
+# 非法的套餐类型
+INVALIDPARAMETERVALUE_INVALIDQUOTATYPE = 'InvalidParameterValue.InvalidQuotaType'
+
+# 非法的时间参数
+INVALIDPARAMETERVALUE_INVALIDTIME = 'InvalidParameterValue.InvalidTime'
+
 # 需要屏蔽的告警。
 INVALIDPARAMETERVALUE_MASK = 'InvalidParameterValue.Mask'
 
@@ -377,6 +386,9 @@ MISSINGPARAMETER_FLOWID = 'MissingParameter.FlowId'
 # 未找到关键字配置信息，请检查控件传参，检查文件资源配置，并在修改后重试。
 MISSINGPARAMETER_KEYWORD = 'MissingParameter.KeyWord'
 
+# 缺少机构ID参数。
+MISSINGPARAMETER_ORGANIZATIONID = 'MissingParameter.OrganizationId'
+
 # 缺少签署二维码id，请检查后重试。
 MISSINGPARAMETER_QRCODEID = 'MissingParameter.QrCodeId'
 
@@ -461,6 +473,12 @@ OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
 # 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
 OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'
 
+# 没有API权限。
+OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
+
+# 没有手机号查看的权限
+OPERATIONDENIED_NOAPPROVERMOBILECHECKPERMISSION = 'OperationDenied.NoApproverMobileCheckPermission'
+
 # 无权限操作签署流程，请联系客服了解权限，并在修改后重试。
 OPERATIONDENIED_NOFLOWPERMISSION = 'OperationDenied.NoFlowPermission'
 
@@ -518,6 +536,9 @@ OPERATIONDENIED_PERSONNOOPENSERVERSIGN = 'OperationDenied.PersonNoOpenServerSign
 # 拒绝个人静默签，请检查个人静默签签署人，并在修改后重试。
 OPERATIONDENIED_PERSONSERVERSIGNFORBID = 'OperationDenied.PersonServerSignForbid'
 
+# 出证计费额度不足
+OPERATIONDENIED_PROVENOQUOTA = 'OperationDenied.ProveNoQuota'
+
 # 签署二维码已过期，请检查后重试。
 OPERATIONDENIED_QRHASEXPIRE = 'OperationDenied.QrHasExpire'
 
@@ -572,6 +593,9 @@ RESOURCENOTFOUND_FLOW = 'ResourceNotFound.Flow'
 # 签署流程的签署人不存在，请检查后重试。
 RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'
 
+# 应用号不存在。
+RESOURCENOTFOUND_NOTEXISTAPPLICATION = 'ResourceNotFound.NotExistApplication'
+
 # 电子文档不存在。
 RESOURCENOTFOUND_NOTEXISTDOCUMENT = 'ResourceNotFound.NotExistDocument'
 
