@@ -98,7 +98,7 @@ class DescribeMaterialListResponse(AbstractModel):
         :type MaterialInfos: list of PublicMaterialInfos
         :param _Count: 素材条数
         :type Count: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._MaterialInfos = None
@@ -433,7 +433,7 @@ class FuseFaceResponse(AbstractModel):
         r"""
         :param _FusedImage: RspImgType 为 url 时，返回结果的 url， RspImgType 为 base64 时返回 base64 数据。
         :type FusedImage: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._FusedImage = None
@@ -655,7 +655,7 @@ class MergeInfo(AbstractModel):
         :type InputImageFaceRect: :class:`tencentcloud.facefusion.v20220927.models.FaceRect`
         :param _TemplateFaceID: 素材人脸ID，不填默认取最大人脸。
         :type TemplateFaceID: str
-        :param _TemplateFaceRect: 模版中人脸位置信息(人脸框)，不填默认取最大人脸。此字段仅适用于图片融合自定义模版素材场景。
+        :param _TemplateFaceRect: 模板中人脸位置信息(人脸框)，不填默认取最大人脸。此字段仅适用于图片融合自定义模板素材场景。
         :type TemplateFaceRect: :class:`tencentcloud.facefusion.v20220927.models.FaceRect`
         """
         self._Image = None
